====================================
Details of Lexical Richness Measures
====================================

The two fundamental building blocks of all the measures are: 

* the total number of words in the text (*w*)  , and
* the number of unique terms (*t*).
----

**TTR:** Type-Token Ratio (*Chotlos 1944, Templin 1957*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/ttr.svg
   :alt: TTR
   :align: center   
----
   
   
**RTTR:** Root Type-Token Ratio (*Guiraud 1954, 1960*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/rttr.svg
   :alt: TTR
   :align: center   
----

**CTTR:** Corrected Type-Token Ratio (*Carrol 1964*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/cttr.svg
   :alt: TTR
   :align: center   
----

**Herdan**: Herdan's C (*Herdan 1960, 1964*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/herdan.svg
   :alt: Herdan's C
   :align: center   
----

**Summer**: Summer (*Summer 1966*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/summer.svg
   :alt: Summer
   :align: center   
----

**Dugast**: Dugast (*Dugast 1978*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/dugast.svg
   :alt: Dugast
   :align: center   
----

**Maas**: Maas (*Maas 1972*)

.. figure:: https://raw.githubusercontent.com/lsys/lexicalrichness/master/docs/assets/eqn-img/maas.svg
   :alt: Maas
   :align: center   
----
